# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class HourlyUsageAttributionUsageType(ModelSimple):
    """
    Supported products for hourly usage attribution requests.

    :param value: Must be one of ["api_usage", "apm_fargate_usage", "apm_host_usage", "appsec_fargate_usage", "appsec_usage", "browser_usage", "container_usage", "cspm_containers_usage", "cspm_hosts_usage", "custom_timeseries_usage", "cws_containers_usage", "cws_hosts_usage", "dbm_hosts_usage", "dbm_queries_usage", "estimated_indexed_logs_usage", "estimated_ingested_logs_usage", "estimated_indexed_spans_usage", "estimated_ingested_spans_usage", "fargate_usage", "functions_usage", "indexed_logs_usage", "infra_host_usage", "invocations_usage", "npm_host_usage", "profiled_container_usage", "profiled_host_usage", "snmp_usage", "estimated_rum_sessions_usage", "cont_usage"].
    :type value: str
    """

    allowed_values = {
        "api_usage",
        "apm_fargate_usage",
        "apm_host_usage",
        "appsec_fargate_usage",
        "appsec_usage",
        "browser_usage",
        "container_usage",
        "cspm_containers_usage",
        "cspm_hosts_usage",
        "custom_timeseries_usage",
        "cws_containers_usage",
        "cws_hosts_usage",
        "dbm_hosts_usage",
        "dbm_queries_usage",
        "estimated_indexed_logs_usage",
        "estimated_ingested_logs_usage",
        "estimated_indexed_spans_usage",
        "estimated_ingested_spans_usage",
        "fargate_usage",
        "functions_usage",
        "indexed_logs_usage",
        "infra_host_usage",
        "invocations_usage",
        "npm_host_usage",
        "profiled_container_usage",
        "profiled_host_usage",
        "snmp_usage",
        "estimated_rum_sessions_usage",
        "cont_usage",
    }
    API_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    APM_FARGATE_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    APM_HOST_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    APPSEC_FARGATE_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    APPSEC_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    BROWSER_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    CONTAINER_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    CSPM_CONTAINERS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    CSPM_HOSTS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    CUSTOM_TIMESERIES_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    CWS_CONTAINERS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    CWS_HOSTS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    DBM_HOSTS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    DBM_QUERIES_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    ESTIMATED_INDEXED_LOGS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    ESTIMATED_INGESTED_LOGS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    ESTIMATED_INDEXED_SPANS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    ESTIMATED_INGESTED_SPANS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    FARGATE_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    FUNCTIONS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    INDEXED_LOGS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    INFRA_HOST_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    INVOCATIONS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    NPM_HOST_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    PROFILED_CONTAINER_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    PROFILED_HOST_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    SNMP_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    ESTIMATED_RUM_SESSIONS_USAGE: ClassVar["HourlyUsageAttributionUsageType"]
    CONT_USAGE: ClassVar["HourlyUsageAttributionUsageType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


HourlyUsageAttributionUsageType.API_USAGE = HourlyUsageAttributionUsageType("api_usage")
HourlyUsageAttributionUsageType.APM_FARGATE_USAGE = HourlyUsageAttributionUsageType("apm_fargate_usage")
HourlyUsageAttributionUsageType.APM_HOST_USAGE = HourlyUsageAttributionUsageType("apm_host_usage")
HourlyUsageAttributionUsageType.APPSEC_FARGATE_USAGE = HourlyUsageAttributionUsageType("appsec_fargate_usage")
HourlyUsageAttributionUsageType.APPSEC_USAGE = HourlyUsageAttributionUsageType("appsec_usage")
HourlyUsageAttributionUsageType.BROWSER_USAGE = HourlyUsageAttributionUsageType("browser_usage")
HourlyUsageAttributionUsageType.CONTAINER_USAGE = HourlyUsageAttributionUsageType("container_usage")
HourlyUsageAttributionUsageType.CSPM_CONTAINERS_USAGE = HourlyUsageAttributionUsageType("cspm_containers_usage")
HourlyUsageAttributionUsageType.CSPM_HOSTS_USAGE = HourlyUsageAttributionUsageType("cspm_hosts_usage")
HourlyUsageAttributionUsageType.CUSTOM_TIMESERIES_USAGE = HourlyUsageAttributionUsageType("custom_timeseries_usage")
HourlyUsageAttributionUsageType.CWS_CONTAINERS_USAGE = HourlyUsageAttributionUsageType("cws_containers_usage")
HourlyUsageAttributionUsageType.CWS_HOSTS_USAGE = HourlyUsageAttributionUsageType("cws_hosts_usage")
HourlyUsageAttributionUsageType.DBM_HOSTS_USAGE = HourlyUsageAttributionUsageType("dbm_hosts_usage")
HourlyUsageAttributionUsageType.DBM_QUERIES_USAGE = HourlyUsageAttributionUsageType("dbm_queries_usage")
HourlyUsageAttributionUsageType.ESTIMATED_INDEXED_LOGS_USAGE = HourlyUsageAttributionUsageType(
    "estimated_indexed_logs_usage"
)
HourlyUsageAttributionUsageType.ESTIMATED_INGESTED_LOGS_USAGE = HourlyUsageAttributionUsageType(
    "estimated_ingested_logs_usage"
)
HourlyUsageAttributionUsageType.ESTIMATED_INDEXED_SPANS_USAGE = HourlyUsageAttributionUsageType(
    "estimated_indexed_spans_usage"
)
HourlyUsageAttributionUsageType.ESTIMATED_INGESTED_SPANS_USAGE = HourlyUsageAttributionUsageType(
    "estimated_ingested_spans_usage"
)
HourlyUsageAttributionUsageType.FARGATE_USAGE = HourlyUsageAttributionUsageType("fargate_usage")
HourlyUsageAttributionUsageType.FUNCTIONS_USAGE = HourlyUsageAttributionUsageType("functions_usage")
HourlyUsageAttributionUsageType.INDEXED_LOGS_USAGE = HourlyUsageAttributionUsageType("indexed_logs_usage")
HourlyUsageAttributionUsageType.INFRA_HOST_USAGE = HourlyUsageAttributionUsageType("infra_host_usage")
HourlyUsageAttributionUsageType.INVOCATIONS_USAGE = HourlyUsageAttributionUsageType("invocations_usage")
HourlyUsageAttributionUsageType.NPM_HOST_USAGE = HourlyUsageAttributionUsageType("npm_host_usage")
HourlyUsageAttributionUsageType.PROFILED_CONTAINER_USAGE = HourlyUsageAttributionUsageType("profiled_container_usage")
HourlyUsageAttributionUsageType.PROFILED_HOST_USAGE = HourlyUsageAttributionUsageType("profiled_host_usage")
HourlyUsageAttributionUsageType.SNMP_USAGE = HourlyUsageAttributionUsageType("snmp_usage")
HourlyUsageAttributionUsageType.ESTIMATED_RUM_SESSIONS_USAGE = HourlyUsageAttributionUsageType(
    "estimated_rum_sessions_usage"
)
HourlyUsageAttributionUsageType.CONT_USAGE = HourlyUsageAttributionUsageType("cont_usage")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.logs_pipelines_order import LogsPipelinesOrder
from datadog_api_client.v1.model.logs_pipeline_list import LogsPipelineList
from datadog_api_client.v1.model.logs_pipeline import LogsPipeline


class LogsPipelinesApi:
    """
    Pipelines and processors operate on incoming logs, parsing
    and transforming them into structured attributes for easier querying.

    *
      See the `pipelines configuration page <https://app.datadoghq.com/logs/pipelines>`_
      for a list of the pipelines and processors currently configured in web UI.

    *
      Additional API-related information about processors can be found in the
      `processors documentation <https://docs.datadoghq.com/logs/log_configuration/processors/?tab=api#lookup-processor>`_.

    *
      For more information about Pipelines, see the
      `pipeline documentation <https://docs.datadoghq.com/logs/log_configuration/pipelines>`_.

    **Notes:**

    These endpoints are only available for admin users.
    Make sure to use an application key created by an admin.

    **Grok parsing rules may effect JSON output and require
    returned data to be configured before using in a request.**
    For example, if you are using the data returned from a
    request for another request body, and have a parsing rule
    that uses a regex pattern like ``\s`` for spaces, you will
    need to configure all escaped spaces as ``%{space}`` to use
    in the body data.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_logs_pipeline_endpoint = _Endpoint(
            settings={
                "response_type": (LogsPipeline,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/logs/config/pipelines",
                "operation_id": "create_logs_pipeline",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (LogsPipeline,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_logs_pipeline_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/logs/config/pipelines/{pipeline_id}",
                "operation_id": "delete_logs_pipeline",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "pipeline_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "pipeline_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_logs_pipeline_endpoint = _Endpoint(
            settings={
                "response_type": (LogsPipeline,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/logs/config/pipelines/{pipeline_id}",
                "operation_id": "get_logs_pipeline",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "pipeline_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "pipeline_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_logs_pipeline_order_endpoint = _Endpoint(
            settings={
                "response_type": (LogsPipelinesOrder,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/logs/config/pipeline-order",
                "operation_id": "get_logs_pipeline_order",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_logs_pipelines_endpoint = _Endpoint(
            settings={
                "response_type": (LogsPipelineList,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/logs/config/pipelines",
                "operation_id": "list_logs_pipelines",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_logs_pipeline_endpoint = _Endpoint(
            settings={
                "response_type": (LogsPipeline,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/logs/config/pipelines/{pipeline_id}",
                "operation_id": "update_logs_pipeline",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "pipeline_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "pipeline_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (LogsPipeline,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_logs_pipeline_order_endpoint = _Endpoint(
            settings={
                "response_type": (LogsPipelinesOrder,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/logs/config/pipeline-order",
                "operation_id": "update_logs_pipeline_order",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (LogsPipelinesOrder,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_logs_pipeline(
        self,
        body: LogsPipeline,
    ) -> LogsPipeline:
        """Create a pipeline.

        Create a pipeline in your organization.

        :param body: Definition of the new pipeline.
        :type body: LogsPipeline
        :rtype: LogsPipeline
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_logs_pipeline_endpoint.call_with_http_info(**kwargs)

    def delete_logs_pipeline(
        self,
        pipeline_id: str,
    ) -> None:
        """Delete a pipeline.

        Delete a given pipeline from your organization.
        This endpoint takes no JSON arguments.

        :param pipeline_id: ID of the pipeline to delete.
        :type pipeline_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["pipeline_id"] = pipeline_id

        return self._delete_logs_pipeline_endpoint.call_with_http_info(**kwargs)

    def get_logs_pipeline(
        self,
        pipeline_id: str,
    ) -> LogsPipeline:
        """Get a pipeline.

        Get a specific pipeline from your organization.
        This endpoint takes no JSON arguments.

        :param pipeline_id: ID of the pipeline to get.
        :type pipeline_id: str
        :rtype: LogsPipeline
        """
        kwargs: Dict[str, Any] = {}
        kwargs["pipeline_id"] = pipeline_id

        return self._get_logs_pipeline_endpoint.call_with_http_info(**kwargs)

    def get_logs_pipeline_order(
        self,
    ) -> LogsPipelinesOrder:
        """Get pipeline order.

        Get the current order of your pipelines.
        This endpoint takes no JSON arguments.

        :rtype: LogsPipelinesOrder
        """
        kwargs: Dict[str, Any] = {}
        return self._get_logs_pipeline_order_endpoint.call_with_http_info(**kwargs)

    def list_logs_pipelines(
        self,
    ) -> LogsPipelineList:
        """Get all pipelines.

        Get all pipelines from your organization.
        This endpoint takes no JSON arguments.

        :rtype: LogsPipelineList
        """
        kwargs: Dict[str, Any] = {}
        return self._list_logs_pipelines_endpoint.call_with_http_info(**kwargs)

    def update_logs_pipeline(
        self,
        pipeline_id: str,
        body: LogsPipeline,
    ) -> LogsPipeline:
        """Update a pipeline.

        Update a given pipeline configuration to change it’s processors or their order.

        **Note** : Using this method updates your pipeline configuration by **replacing**
        your current configuration with the new one sent to your Datadog organization.

        :param pipeline_id: ID of the pipeline to delete.
        :type pipeline_id: str
        :param body: New definition of the pipeline.
        :type body: LogsPipeline
        :rtype: LogsPipeline
        """
        kwargs: Dict[str, Any] = {}
        kwargs["pipeline_id"] = pipeline_id

        kwargs["body"] = body

        return self._update_logs_pipeline_endpoint.call_with_http_info(**kwargs)

    def update_logs_pipeline_order(
        self,
        body: LogsPipelinesOrder,
    ) -> LogsPipelinesOrder:
        """Update pipeline order.

        Update the order of your pipelines. Since logs are processed sequentially, reordering a pipeline may change
        the structure and content of the data processed by other pipelines and their processors.

        **Note** : Using the ``PUT`` method updates your pipeline order by replacing your current order
        with the new one sent to your Datadog organization.

        :param body: Object containing the new ordered list of pipeline IDs.
        :type body: LogsPipelinesOrder
        :rtype: LogsPipelinesOrder
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._update_logs_pipeline_order_endpoint.call_with_http_info(**kwargs)



"""
Edit an AuthN Mapping returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.authn_mappings_api import AuthNMappingsApi
from datadog_api_client.v2.model.authn_mapping_update_attributes import AuthNMappingUpdateAttributes
from datadog_api_client.v2.model.authn_mapping_update_data import AuthNMappingUpdateData
from datadog_api_client.v2.model.authn_mapping_update_relationships import AuthNMappingUpdateRelationships
from datadog_api_client.v2.model.authn_mapping_update_request import AuthNMappingUpdateRequest
from datadog_api_client.v2.model.authn_mappings_type import AuthNMappingsType
from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole
from datadog_api_client.v2.model.relationship_to_role_data import RelationshipToRoleData
from datadog_api_client.v2.model.roles_type import RolesType

# there is a valid "authn_mapping" in the system
AUTHN_MAPPING_DATA_ID = environ["AUTHN_MAPPING_DATA_ID"]

# there is a valid "role" in the system
ROLE_DATA_ID = environ["ROLE_DATA_ID"]

body = AuthNMappingUpdateRequest(
    data=AuthNMappingUpdateData(
        attributes=AuthNMappingUpdateAttributes(
            attribute_key="member-of",
            attribute_value="Development",
        ),
        id=AUTHN_MAPPING_DATA_ID,
        relationships=AuthNMappingUpdateRelationships(
            role=RelationshipToRole(
                data=RelationshipToRoleData(
                    id=ROLE_DATA_ID,
                    type=RolesType.ROLES,
                ),
            ),
        ),
        type=AuthNMappingsType.AUTHN_MAPPINGS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AuthNMappingsApi(api_client)
    response = api_instance.update_authn_mapping(authn_mapping_id=AUTHN_MAPPING_DATA_ID, body=body)

    print(response)



"""
Schedule a downtime until date
"""

from datetime import datetime
from dateutil.relativedelta import relativedelta
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.downtimes_api import DowntimesApi
from datadog_api_client.v1.model.downtime import Downtime
from datadog_api_client.v1.model.downtime_recurrence import DowntimeRecurrence

body = Downtime(
    message="Example-Schedule_a_downtime_until_date",
    recurrence=DowntimeRecurrence(
        period=1,
        type="weeks",
        until_date=int((datetime.now() + relativedelta(days=21)).timestamp()),
        week_days=[
            "Mon",
            "Tue",
            "Wed",
            "Thu",
            "Fri",
        ],
    ),
    scope=[
        "*",
    ],
    start=int(datetime.now().timestamp()),
    end=int((datetime.now() + relativedelta(hours=1)).timestamp()),
    timezone="Etc/UTC",
    mute_first_recovery_notification=True,
    monitor_tags=[
        "tag0",
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DowntimesApi(api_client)
    response = api_instance.create_downtime(body=body)

    print(response)



"""
Get a list of RUM events returns "OK" response with pagination
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.rum_api import RUMApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RUMApi(api_client)
    items = api_instance.list_rum_events_with_pagination(
        page_limit=2,
    )
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SyntheticsTestOptionsMonitorOptions(ModelNormal):
    validations = {
        "renotify_interval": {
            "inclusive_maximum": 1440,
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "renotify_interval": (int,),
        }

    attribute_map = {
        "renotify_interval": "renotify_interval",
    }

    def __init__(self_, renotify_interval: Union[int, UnsetType] = unset, **kwargs):
        """
        Object containing the options for a Synthetic test as a monitor
        (for example, renotification).

        :param renotify_interval: Time interval before renotifying if the test is still failing
            (in minutes).
        :type renotify_interval: int, optional
        """
        if renotify_interval is not unset:
            kwargs["renotify_interval"] = renotify_interval
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monthly_usage_attribution_metadata import MonthlyUsageAttributionMetadata
    from datadog_api_client.v1.model.monthly_usage_attribution_body import MonthlyUsageAttributionBody


class MonthlyUsageAttributionResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monthly_usage_attribution_metadata import MonthlyUsageAttributionMetadata
        from datadog_api_client.v1.model.monthly_usage_attribution_body import MonthlyUsageAttributionBody

        return {
            "metadata": (MonthlyUsageAttributionMetadata,),
            "usage": ([MonthlyUsageAttributionBody],),
        }

    attribute_map = {
        "metadata": "metadata",
        "usage": "usage",
    }

    def __init__(
        self_,
        metadata: Union[MonthlyUsageAttributionMetadata, UnsetType] = unset,
        usage: Union[List[MonthlyUsageAttributionBody], UnsetType] = unset,
        **kwargs,
    ):
        """
        Response containing the monthly Usage Summary by tag(s).

        :param metadata: The object containing document metadata.
        :type metadata: MonthlyUsageAttributionMetadata, optional

        :param usage: Get usage summary by tag(s).
        :type usage: [MonthlyUsageAttributionBody], optional
        """
        if metadata is not unset:
            kwargs["metadata"] = metadata
        if usage is not unset:
            kwargs["usage"] = usage
        super().__init__(kwargs)



"""
Create a child organization returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.organizations_api import OrganizationsApi
from datadog_api_client.v1.model.organization_billing import OrganizationBilling
from datadog_api_client.v1.model.organization_create_body import OrganizationCreateBody
from datadog_api_client.v1.model.organization_subscription import OrganizationSubscription

body = OrganizationCreateBody(
    billing=OrganizationBilling(
        type="parent_billing",
    ),
    name="New child org",
    subscription=OrganizationSubscription(
        type="pro",
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = OrganizationsApi(api_client)
    response = api_instance.create_child_org(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_global_variable import SyntheticsGlobalVariable


class SyntheticsListGlobalVariablesResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_global_variable import SyntheticsGlobalVariable

        return {
            "variables": ([SyntheticsGlobalVariable],),
        }

    attribute_map = {
        "variables": "variables",
    }

    def __init__(self_, variables: Union[List[SyntheticsGlobalVariable], UnsetType] = unset, **kwargs):
        """
        Object containing an array of Synthetic global variables.

        :param variables: Array of Synthetic global variables.
        :type variables: [SyntheticsGlobalVariable], optional
        """
        if variables is not unset:
            kwargs["variables"] = variables
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole
    from datadog_api_client.v2.model.relationship_to_saml_assertion_attribute import (
        RelationshipToSAMLAssertionAttribute,
    )


class AuthNMappingRelationships(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole
        from datadog_api_client.v2.model.relationship_to_saml_assertion_attribute import (
            RelationshipToSAMLAssertionAttribute,
        )

        return {
            "role": (RelationshipToRole,),
            "saml_assertion_attribute": (RelationshipToSAMLAssertionAttribute,),
        }

    attribute_map = {
        "role": "role",
        "saml_assertion_attribute": "saml_assertion_attribute",
    }

    def __init__(
        self_,
        role: Union[RelationshipToRole, UnsetType] = unset,
        saml_assertion_attribute: Union[RelationshipToSAMLAssertionAttribute, UnsetType] = unset,
        **kwargs,
    ):
        """
        All relationships associated with AuthN Mapping.

        :param role: Relationship to role.
        :type role: RelationshipToRole, optional

        :param saml_assertion_attribute: AuthN Mapping relationship to SAML Assertion Attribute.
        :type saml_assertion_attribute: RelationshipToSAMLAssertionAttribute, optional
        """
        if role is not unset:
            kwargs["role"] = role
        if saml_assertion_attribute is not unset:
            kwargs["saml_assertion_attribute"] = saml_assertion_attribute
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.aws_account_and_lambda_request import AWSAccountAndLambdaRequest
from datadog_api_client.v1.model.aws_logs_list_response import AWSLogsListResponse
from datadog_api_client.v1.model.aws_logs_async_response import AWSLogsAsyncResponse
from datadog_api_client.v1.model.aws_logs_list_services_response import AWSLogsListServicesResponse
from datadog_api_client.v1.model.aws_logs_services_request import AWSLogsServicesRequest


class AWSLogsIntegrationApi:
    """
    Configure your Datadog-AWS-Logs integration directly through Datadog API.
    For more information, see the `AWS integration page <https://docs.datadoghq.com/api/?lang=bash#integration-aws-logs>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._check_aws_logs_lambda_async_endpoint = _Endpoint(
            settings={
                "response_type": (AWSLogsAsyncResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/integration/aws/logs/check_async",
                "operation_id": "check_aws_logs_lambda_async",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSAccountAndLambdaRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._check_aws_logs_services_async_endpoint = _Endpoint(
            settings={
                "response_type": (AWSLogsAsyncResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/logs/services_async",
                "operation_id": "check_aws_logs_services_async",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSLogsServicesRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_aws_lambda_arn_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/logs",
                "operation_id": "create_aws_lambda_arn",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSAccountAndLambdaRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_aws_lambda_arn_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/logs",
                "operation_id": "delete_aws_lambda_arn",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSAccountAndLambdaRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._enable_aws_log_services_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/logs/services",
                "operation_id": "enable_aws_log_services",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSLogsServicesRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._list_aws_logs_integrations_endpoint = _Endpoint(
            settings={
                "response_type": ([AWSLogsListResponse],),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/logs",
                "operation_id": "list_aws_logs_integrations",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_aws_logs_services_endpoint = _Endpoint(
            settings={
                "response_type": ([AWSLogsListServicesResponse],),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/logs/services",
                "operation_id": "list_aws_logs_services",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

    def check_aws_logs_lambda_async(
        self,
        body: AWSAccountAndLambdaRequest,
    ) -> AWSLogsAsyncResponse:
        """Check that an AWS Lambda Function exists.

        Test if permissions are present to add a log-forwarding triggers for the given services and AWS account. The input
        is the same as for Enable an AWS service log collection. Subsequent requests will always repeat the above, so this
        endpoint can be polled intermittently instead of blocking.

        * Returns a status of 'created' when it's checking if the Lambda exists in the account.
        * Returns a status of 'waiting' while checking.
        * Returns a status of 'checked and ok' if the Lambda exists.
        * Returns a status of 'error' if the Lambda does not exist.

        :param body: Check AWS Log Lambda Async request body.
        :type body: AWSAccountAndLambdaRequest
        :rtype: AWSLogsAsyncResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._check_aws_logs_lambda_async_endpoint.call_with_http_info(**kwargs)

    def check_aws_logs_services_async(
        self,
        body: AWSLogsServicesRequest,
    ) -> AWSLogsAsyncResponse:
        """Check permissions for log services.

        Test if permissions are present to add log-forwarding triggers for the
        given services and AWS account. Input is the same as for ``EnableAWSLogServices``.
        Done async, so can be repeatedly polled in a non-blocking fashion until
        the async request completes.

        * Returns a status of ``created`` when it's checking if the permissions exists
          in the AWS account.
        * Returns a status of ``waiting`` while checking.
        * Returns a status of ``checked and ok`` if the Lambda exists.
        * Returns a status of ``error`` if the Lambda does not exist.

        :param body: Check AWS Logs Async Services request body.
        :type body: AWSLogsServicesRequest
        :rtype: AWSLogsAsyncResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._check_aws_logs_services_async_endpoint.call_with_http_info(**kwargs)

    def create_aws_lambda_arn(
        self,
        body: AWSAccountAndLambdaRequest,
    ) -> dict:
        """Add AWS Log Lambda ARN.

        Attach the Lambda ARN of the Lambda created for the Datadog-AWS log collection to your AWS account ID to enable log collection.

        :param body: AWS Log Lambda Async request body.
        :type body: AWSAccountAndLambdaRequest
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_aws_lambda_arn_endpoint.call_with_http_info(**kwargs)

    def delete_aws_lambda_arn(
        self,
        body: AWSAccountAndLambdaRequest,
    ) -> dict:
        """Delete an AWS Logs integration.

        Delete a Datadog-AWS logs configuration by removing the specific Lambda ARN associated with a given AWS account.

        :param body: Delete AWS Lambda ARN request body.
        :type body: AWSAccountAndLambdaRequest
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._delete_aws_lambda_arn_endpoint.call_with_http_info(**kwargs)

    def enable_aws_log_services(
        self,
        body: AWSLogsServicesRequest,
    ) -> dict:
        """Enable an AWS Logs integration.

        Enable automatic log collection for a list of services. This should be run after running ``CreateAWSLambdaARN`` to save the configuration.

        :param body: Enable AWS Log Services request body.
        :type body: AWSLogsServicesRequest
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._enable_aws_log_services_endpoint.call_with_http_info(**kwargs)

    def list_aws_logs_integrations(
        self,
    ) -> List[AWSLogsListResponse]:
        """List all AWS Logs integrations.

        List all Datadog-AWS Logs integrations configured in your Datadog account.

        :rtype: [AWSLogsListResponse]
        """
        kwargs: Dict[str, Any] = {}
        return self._list_aws_logs_integrations_endpoint.call_with_http_info(**kwargs)

    def list_aws_logs_services(
        self,
    ) -> List[AWSLogsListServicesResponse]:
        """Get list of AWS log ready services.

        Get the list of current AWS services that Datadog offers automatic log collection. Use returned service IDs with the services parameter for the Enable an AWS service log collection API endpoint.

        :rtype: [AWSLogsListServicesResponse]
        """
        kwargs: Dict[str, Any] = {}
        return self._list_aws_logs_services_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class FormulaAndFunctionMetricAggregation(ModelSimple):
    """
    The aggregation methods available for metrics queries.

    :param value: Must be one of ["avg", "min", "max", "sum", "last", "area", "l2norm", "percentile"].
    :type value: str
    """

    allowed_values = {
        "avg",
        "min",
        "max",
        "sum",
        "last",
        "area",
        "l2norm",
        "percentile",
    }
    AVG: ClassVar["FormulaAndFunctionMetricAggregation"]
    MIN: ClassVar["FormulaAndFunctionMetricAggregation"]
    MAX: ClassVar["FormulaAndFunctionMetricAggregation"]
    SUM: ClassVar["FormulaAndFunctionMetricAggregation"]
    LAST: ClassVar["FormulaAndFunctionMetricAggregation"]
    AREA: ClassVar["FormulaAndFunctionMetricAggregation"]
    L2NORM: ClassVar["FormulaAndFunctionMetricAggregation"]
    PERCENTILE: ClassVar["FormulaAndFunctionMetricAggregation"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


FormulaAndFunctionMetricAggregation.AVG = FormulaAndFunctionMetricAggregation("avg")
FormulaAndFunctionMetricAggregation.MIN = FormulaAndFunctionMetricAggregation("min")
FormulaAndFunctionMetricAggregation.MAX = FormulaAndFunctionMetricAggregation("max")
FormulaAndFunctionMetricAggregation.SUM = FormulaAndFunctionMetricAggregation("sum")
FormulaAndFunctionMetricAggregation.LAST = FormulaAndFunctionMetricAggregation("last")
FormulaAndFunctionMetricAggregation.AREA = FormulaAndFunctionMetricAggregation("area")
FormulaAndFunctionMetricAggregation.L2NORM = FormulaAndFunctionMetricAggregation("l2norm")
FormulaAndFunctionMetricAggregation.PERCENTILE = FormulaAndFunctionMetricAggregation("percentile")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
    from datadog_api_client.v1.model.synthetics_batch_result import SyntheticsBatchResult
    from datadog_api_client.v1.model.synthetics_status import SyntheticsStatus


class SyntheticsBatchDetailsData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
        from datadog_api_client.v1.model.synthetics_batch_result import SyntheticsBatchResult
        from datadog_api_client.v1.model.synthetics_status import SyntheticsStatus

        return {
            "metadata": (SyntheticsCIBatchMetadata,),
            "results": ([SyntheticsBatchResult],),
            "status": (SyntheticsStatus,),
        }

    attribute_map = {
        "metadata": "metadata",
        "results": "results",
        "status": "status",
    }

    def __init__(
        self_,
        metadata: Union[SyntheticsCIBatchMetadata, UnsetType] = unset,
        results: Union[List[SyntheticsBatchResult], UnsetType] = unset,
        status: Union[SyntheticsStatus, UnsetType] = unset,
        **kwargs,
    ):
        """
        Wrapper object that contains the details of a batch.

        :param metadata: Metadata for the Synthetics tests run.
        :type metadata: SyntheticsCIBatchMetadata, optional

        :param results: List of results for the batch.
        :type results: [SyntheticsBatchResult], optional

        :param status: Determines whether or not the batch has passed, failed, or is in progress.
        :type status: SyntheticsStatus, optional
        """
        if metadata is not unset:
            kwargs["metadata"] = metadata
        if results is not unset:
            kwargs["results"] = results
        if status is not unset:
            kwargs["status"] = status
        super().__init__(kwargs)



"""
Delete a monitor returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.monitors_api import MonitorsApi

# there is a valid "monitor" in the system
MONITOR_ID = environ["MONITOR_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MonitorsApi(api_client)
    response = api_instance.delete_monitor(
        monitor_id=int(MONITOR_ID),
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.host import Host


class HostListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.host import Host

        return {
            "host_list": ([Host],),
            "total_matching": (int,),
            "total_returned": (int,),
        }

    attribute_map = {
        "host_list": "host_list",
        "total_matching": "total_matching",
        "total_returned": "total_returned",
    }

    def __init__(
        self_,
        host_list: Union[List[Host], UnsetType] = unset,
        total_matching: Union[int, UnsetType] = unset,
        total_returned: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response with Host information from Datadog.

        :param host_list: Array of hosts.
        :type host_list: [Host], optional

        :param total_matching: Number of host matching the query.
        :type total_matching: int, optional

        :param total_returned: Number of host returned.
        :type total_returned: int, optional
        """
        if host_list is not unset:
            kwargs["host_list"] = host_list
        if total_matching is not unset:
            kwargs["total_matching"] = total_matching
        if total_returned is not unset:
            kwargs["total_returned"] = total_returned
        super().__init__(kwargs)



"""
Update a custom variable returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.webhooks_integration_api import WebhooksIntegrationApi
from datadog_api_client.v1.model.webhooks_integration_custom_variable_update_request import (
    WebhooksIntegrationCustomVariableUpdateRequest,
)

# there is a valid "webhook_custom_variable" in the system
WEBHOOK_CUSTOM_VARIABLE_NAME = environ["WEBHOOK_CUSTOM_VARIABLE_NAME"]

body = WebhooksIntegrationCustomVariableUpdateRequest(
    value="variable-updated",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = WebhooksIntegrationApi(api_client)
    response = api_instance.update_webhooks_integration_custom_variable(
        custom_variable_name=WEBHOOK_CUSTOM_VARIABLE_NAME, body=body
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v2.model.sensitive_data_scanner_get_config_response import SensitiveDataScannerGetConfigResponse
from datadog_api_client.v2.model.sensitive_data_scanner_reorder_groups_response import (
    SensitiveDataScannerReorderGroupsResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_config_request import SensitiveDataScannerConfigRequest
from datadog_api_client.v2.model.sensitive_data_scanner_create_group_response import (
    SensitiveDataScannerCreateGroupResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_create_request import (
    SensitiveDataScannerGroupCreateRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_delete_response import (
    SensitiveDataScannerGroupDeleteResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_delete_request import (
    SensitiveDataScannerGroupDeleteRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_update_response import (
    SensitiveDataScannerGroupUpdateResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_update_request import (
    SensitiveDataScannerGroupUpdateRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_create_rule_response import (
    SensitiveDataScannerCreateRuleResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_rule_create_request import SensitiveDataScannerRuleCreateRequest
from datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_response import (
    SensitiveDataScannerRuleDeleteResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_request import SensitiveDataScannerRuleDeleteRequest
from datadog_api_client.v2.model.sensitive_data_scanner_rule_update_response import (
    SensitiveDataScannerRuleUpdateResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_rule_update_request import SensitiveDataScannerRuleUpdateRequest
from datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response_data import (
    SensitiveDataScannerStandardPatternsResponseData,
)


class SensitiveDataScannerApi:
    """
    Create, update, delete, and retrieve sensitive data scanner groups and rules.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_scanning_group_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerCreateGroupResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config/groups",
                "operation_id": "create_scanning_group",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SensitiveDataScannerGroupCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_scanning_rule_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerCreateRuleResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config/rules",
                "operation_id": "create_scanning_rule",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SensitiveDataScannerRuleCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_scanning_group_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerGroupDeleteResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config/groups/{group_id}",
                "operation_id": "delete_scanning_group",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "group_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "group_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SensitiveDataScannerGroupDeleteRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_scanning_rule_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerRuleDeleteResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config/rules/{rule_id}",
                "operation_id": "delete_scanning_rule",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "rule_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "rule_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SensitiveDataScannerRuleDeleteRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._list_scanning_groups_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerGetConfigResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config",
                "operation_id": "list_scanning_groups",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_standard_patterns_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerStandardPatternsResponseData,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config/standard-patterns",
                "operation_id": "list_standard_patterns",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._reorder_scanning_groups_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerReorderGroupsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config",
                "operation_id": "reorder_scanning_groups",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (SensitiveDataScannerConfigRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_scanning_group_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerGroupUpdateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config/groups/{group_id}",
                "operation_id": "update_scanning_group",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "group_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "group_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SensitiveDataScannerGroupUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_scanning_rule_endpoint = _Endpoint(
            settings={
                "response_type": (SensitiveDataScannerRuleUpdateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/sensitive-data-scanner/config/rules/{rule_id}",
                "operation_id": "update_scanning_rule",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "rule_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "rule_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (SensitiveDataScannerRuleUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_scanning_group(
        self,
        body: SensitiveDataScannerGroupCreateRequest,
    ) -> SensitiveDataScannerCreateGroupResponse:
        """Create Scanning Group.

        Create a scanning group.
        The request MAY include a configuration relationship.
        A rules relationship can be omitted entirely, but if it is included it MUST be
        null or an empty array (rules cannot be created at the same time).
        The new group will be ordered last within the configuration.

        :type body: SensitiveDataScannerGroupCreateRequest
        :rtype: SensitiveDataScannerCreateGroupResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_scanning_group_endpoint.call_with_http_info(**kwargs)

    def create_scanning_rule(
        self,
        body: SensitiveDataScannerRuleCreateRequest,
    ) -> SensitiveDataScannerCreateRuleResponse:
        """Create Scanning Rule.

        Create a scanning rule in a sensitive data scanner group, ordered last.
        The posted rule MUST include a group relationship.
        It MUST include either a standard_pattern relationship or a regex attribute, but not both.
        If included_attributes is empty or missing, we will scan all attributes except
        excluded_attributes. If both are missing, we will scan the whole event.

        :type body: SensitiveDataScannerRuleCreateRequest
        :rtype: SensitiveDataScannerCreateRuleResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_scanning_rule_endpoint.call_with_http_info(**kwargs)

    def delete_scanning_group(
        self,
        group_id: str,
        body: SensitiveDataScannerGroupDeleteRequest,
    ) -> SensitiveDataScannerGroupDeleteResponse:
        """Delete Scanning Group.

        Delete a given group.

        :param group_id: The ID of a group of rules.
        :type group_id: str
        :type body: SensitiveDataScannerGroupDeleteRequest
        :rtype: SensitiveDataScannerGroupDeleteResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["group_id"] = group_id

        kwargs["body"] = body

        return self._delete_scanning_group_endpoint.call_with_http_info(**kwargs)

    def delete_scanning_rule(
        self,
        rule_id: str,
        body: SensitiveDataScannerRuleDeleteRequest,
    ) -> SensitiveDataScannerRuleDeleteResponse:
        """Delete Scanning Rule.

        Delete a given rule.

        :param rule_id: The ID of the rule.
        :type rule_id: str
        :type body: SensitiveDataScannerRuleDeleteRequest
        :rtype: SensitiveDataScannerRuleDeleteResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["rule_id"] = rule_id

        kwargs["body"] = body

        return self._delete_scanning_rule_endpoint.call_with_http_info(**kwargs)

    def list_scanning_groups(
        self,
    ) -> SensitiveDataScannerGetConfigResponse:
        """List Scanning Groups.

        List all the Scanning groups in your organization.

        :rtype: SensitiveDataScannerGetConfigResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_scanning_groups_endpoint.call_with_http_info(**kwargs)

    def list_standard_patterns(
        self,
    ) -> SensitiveDataScannerStandardPatternsResponseData:
        """List standard patterns.

        Returns all standard patterns.

        :rtype: SensitiveDataScannerStandardPatternsResponseData
        """
        kwargs: Dict[str, Any] = {}
        return self._list_standard_patterns_endpoint.call_with_http_info(**kwargs)

    def reorder_scanning_groups(
        self,
        body: SensitiveDataScannerConfigRequest,
    ) -> SensitiveDataScannerReorderGroupsResponse:
        """Reorder Groups.

        Reorder the list of groups.

        :type body: SensitiveDataScannerConfigRequest
        :rtype: SensitiveDataScannerReorderGroupsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._reorder_scanning_groups_endpoint.call_with_http_info(**kwargs)

    def update_scanning_group(
        self,
        group_id: str,
        body: SensitiveDataScannerGroupUpdateRequest,
    ) -> SensitiveDataScannerGroupUpdateResponse:
        """Update Scanning Group.

        Update a group, including the order of the rules.
        Rules within the group are reordered by including a rules relationship. If the rules
        relationship is present, its data section MUST contain linkages for all of the rules
        currently in the group, and MUST NOT contain any others.

        :param group_id: The ID of a group of rules.
        :type group_id: str
        :type body: SensitiveDataScannerGroupUpdateRequest
        :rtype: SensitiveDataScannerGroupUpdateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["group_id"] = group_id

        kwargs["body"] = body

        return self._update_scanning_group_endpoint.call_with_http_info(**kwargs)

    def update_scanning_rule(
        self,
        rule_id: str,
        body: SensitiveDataScannerRuleUpdateRequest,
    ) -> SensitiveDataScannerRuleUpdateResponse:
        """Update Scanning Rule.

        Update a scanning rule.
        The request body MUST NOT include a standard_pattern relationship, as that relationship
        is non-editable. Trying to edit the regex attribute of a rule with a standard_pattern
        relationship will also result in an error.

        :param rule_id: The ID of the rule.
        :type rule_id: str
        :type body: SensitiveDataScannerRuleUpdateRequest
        :rtype: SensitiveDataScannerRuleUpdateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["rule_id"] = rule_id

        kwargs["body"] = body

        return self._update_scanning_rule_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.creator import Creator
    from datadog_api_client.v1.model.monitor_search_result_notification import MonitorSearchResultNotification
    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
    from datadog_api_client.v1.model.monitor_type import MonitorType


class MonitorSearchResult(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.creator import Creator
        from datadog_api_client.v1.model.monitor_search_result_notification import MonitorSearchResultNotification
        from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
        from datadog_api_client.v1.model.monitor_type import MonitorType

        return {
            "classification": (str,),
            "creator": (Creator,),
            "id": (int,),
            "last_triggered_ts": (int, none_type),
            "metrics": ([str],),
            "name": (str,),
            "notifications": ([MonitorSearchResultNotification],),
            "org_id": (int,),
            "query": (str,),
            "scopes": ([str],),
            "status": (MonitorOverallStates,),
            "tags": ([str],),
            "type": (MonitorType,),
        }

    attribute_map = {
        "classification": "classification",
        "creator": "creator",
        "id": "id",
        "last_triggered_ts": "last_triggered_ts",
        "metrics": "metrics",
        "name": "name",
        "notifications": "notifications",
        "org_id": "org_id",
        "query": "query",
        "scopes": "scopes",
        "status": "status",
        "tags": "tags",
        "type": "type",
    }
    read_only_vars = {
        "classification",
        "creator",
        "id",
        "last_triggered_ts",
        "metrics",
        "name",
        "notifications",
        "org_id",
        "status",
        "tags",
    }

    def __init__(
        self_,
        classification: Union[str, UnsetType] = unset,
        creator: Union[Creator, UnsetType] = unset,
        id: Union[int, UnsetType] = unset,
        last_triggered_ts: Union[int, none_type, UnsetType] = unset,
        metrics: Union[List[str], UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        notifications: Union[List[MonitorSearchResultNotification], UnsetType] = unset,
        org_id: Union[int, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        scopes: Union[List[str], UnsetType] = unset,
        status: Union[MonitorOverallStates, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        type: Union[MonitorType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Holds search results.

        :param classification: Classification of the monitor.
        :type classification: str, optional

        :param creator: Object describing the creator of the shared element.
        :type creator: Creator, optional

        :param id: ID of the monitor.
        :type id: int, optional

        :param last_triggered_ts: Latest timestamp the monitor triggered.
        :type last_triggered_ts: int, none_type, optional

        :param metrics: Metrics used by the monitor.
        :type metrics: [str], optional

        :param name: The monitor name.
        :type name: str, optional

        :param notifications: The notification triggered by the monitor.
        :type notifications: [MonitorSearchResultNotification], optional

        :param org_id: The ID of the organization.
        :type org_id: int, optional

        :param query: The monitor query.
        :type query: str, optional

        :param scopes: The scope(s) to which the downtime applies, for example ``host:app2``.
            Provide multiple scopes as a comma-separated list, for example ``env:dev,env:prod``.
            The resulting downtime applies to sources that matches ALL provided scopes
            (that is ``env:dev AND env:prod`` ), NOT any of them.
        :type scopes: [str], optional

        :param status: The different states your monitor can be in.
        :type status: MonitorOverallStates, optional

        :param tags: Tags associated with the monitor.
        :type tags: [str], optional

        :param type: The type of the monitor. For more information about ``type`` , see the `monitor options <https://docs.datadoghq.com/monitors/guide/monitor_api_options/>`_ docs.
        :type type: MonitorType, optional
        """
        if classification is not unset:
            kwargs["classification"] = classification
        if creator is not unset:
            kwargs["creator"] = creator
        if id is not unset:
            kwargs["id"] = id
        if last_triggered_ts is not unset:
            kwargs["last_triggered_ts"] = last_triggered_ts
        if metrics is not unset:
            kwargs["metrics"] = metrics
        if name is not unset:
            kwargs["name"] = name
        if notifications is not unset:
            kwargs["notifications"] = notifications
        if org_id is not unset:
            kwargs["org_id"] = org_id
        if query is not unset:
            kwargs["query"] = query
        if scopes is not unset:
            kwargs["scopes"] = scopes
        if status is not unset:
            kwargs["status"] = status
        if tags is not unset:
            kwargs["tags"] = tags
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



"""
Update a user returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.users_api import UsersApi
from datadog_api_client.v2.model.user_update_attributes import UserUpdateAttributes
from datadog_api_client.v2.model.user_update_data import UserUpdateData
from datadog_api_client.v2.model.user_update_request import UserUpdateRequest
from datadog_api_client.v2.model.users_type import UsersType

# there is a valid "user" in the system
USER_DATA_ID = environ["USER_DATA_ID"]

body = UserUpdateRequest(
    data=UserUpdateData(
        id=USER_DATA_ID,
        type=UsersType.USERS,
        attributes=UserUpdateAttributes(
            name="updated",
            disabled=True,
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = UsersApi(api_client)
    response = api_instance.update_user(user_id=USER_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.dashboard_list_item_response import DashboardListItemResponse


class DashboardListAddItemsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.dashboard_list_item_response import DashboardListItemResponse

        return {
            "added_dashboards_to_list": ([DashboardListItemResponse],),
        }

    attribute_map = {
        "added_dashboards_to_list": "added_dashboards_to_list",
    }

    def __init__(self_, added_dashboards_to_list: Union[List[DashboardListItemResponse], UnsetType] = unset, **kwargs):
        """
        Response containing a list of added dashboards.

        :param added_dashboards_to_list: List of dashboards added to the dashboard list.
        :type added_dashboards_to_list: [DashboardListItemResponse], optional
        """
        if added_dashboards_to_list is not unset:
            kwargs["added_dashboards_to_list"] = added_dashboards_to_list
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsTestPauseStatus(ModelSimple):
    """
    Define whether you want to start (`live`) or pause (`paused`) a
        Synthetic test.

    :param value: Must be one of ["live", "paused"].
    :type value: str
    """

    allowed_values = {
        "live",
        "paused",
    }
    LIVE: ClassVar["SyntheticsTestPauseStatus"]
    PAUSED: ClassVar["SyntheticsTestPauseStatus"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsTestPauseStatus.LIVE = SyntheticsTestPauseStatus("live")
SyntheticsTestPauseStatus.PAUSED = SyntheticsTestPauseStatus("paused")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_lookup_processor_type import LogsLookupProcessorType


class LogsLookupProcessor(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_lookup_processor_type import LogsLookupProcessorType

        return {
            "default_lookup": (str,),
            "is_enabled": (bool,),
            "lookup_table": ([str],),
            "name": (str,),
            "source": (str,),
            "target": (str,),
            "type": (LogsLookupProcessorType,),
        }

    attribute_map = {
        "default_lookup": "default_lookup",
        "is_enabled": "is_enabled",
        "lookup_table": "lookup_table",
        "name": "name",
        "source": "source",
        "target": "target",
        "type": "type",
    }

    def __init__(
        self_,
        lookup_table: List[str],
        source: str,
        target: str,
        type: LogsLookupProcessorType,
        default_lookup: Union[str, UnsetType] = unset,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Use the Lookup Processor to define a mapping between a log attribute
        and a human readable value saved in the processors mapping table.
        For example, you can use the Lookup Processor to map an internal service ID
        into a human readable service name. Alternatively, you could also use it to check
        if the MAC address that just attempted to connect to the production
        environment belongs to your list of stolen machines.

        :param default_lookup: Value to set the target attribute if the source value is not found in the list.
        :type default_lookup: str, optional

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param lookup_table: Mapping table of values for the source attribute and their associated target attribute values,
            formatted as ``["source_key1,target_value1", "source_key2,target_value2"]``
        :type lookup_table: [str]

        :param name: Name of the processor.
        :type name: str, optional

        :param source: Source attribute used to perform the lookup.
        :type source: str

        :param target: Name of the attribute that contains the corresponding value in the mapping list
            or the ``default_lookup`` if not found in the mapping list.
        :type target: str

        :param type: Type of logs lookup processor.
        :type type: LogsLookupProcessorType
        """
        if default_lookup is not unset:
            kwargs["default_lookup"] = default_lookup
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.lookup_table = lookup_table
        self_.source = source
        self_.target = target
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_metric_response_compute_aggregation_type import (
        LogsMetricResponseComputeAggregationType,
    )


class LogsMetricResponseCompute(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_metric_response_compute_aggregation_type import (
            LogsMetricResponseComputeAggregationType,
        )

        return {
            "aggregation_type": (LogsMetricResponseComputeAggregationType,),
            "include_percentiles": (bool,),
            "path": (str,),
        }

    attribute_map = {
        "aggregation_type": "aggregation_type",
        "include_percentiles": "include_percentiles",
        "path": "path",
    }

    def __init__(
        self_,
        aggregation_type: Union[LogsMetricResponseComputeAggregationType, UnsetType] = unset,
        include_percentiles: Union[bool, UnsetType] = unset,
        path: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The compute rule to compute the log-based metric.

        :param aggregation_type: The type of aggregation to use.
        :type aggregation_type: LogsMetricResponseComputeAggregationType, optional

        :param include_percentiles: Toggle to include or exclude percentile aggregations for distribution metrics.
            Only present when the ``aggregation_type`` is ``distribution``.
        :type include_percentiles: bool, optional

        :param path: The path to the value the log-based metric will aggregate on (only used if the aggregation type is a "distribution").
        :type path: str, optional
        """
        if aggregation_type is not unset:
            kwargs["aggregation_type"] = aggregation_type
        if include_percentiles is not unset:
            kwargs["include_percentiles"] = include_percentiles
        if path is not unset:
            kwargs["path"] = path
        super().__init__(kwargs)



"""
Get a single service object returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.opsgenie_integration_api import OpsgenieIntegrationApi

# there is a valid "opsgenie_service" in the system
OPSGENIE_SERVICE_DATA_ID = environ["OPSGENIE_SERVICE_DATA_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = OpsgenieIntegrationApi(api_client)
    response = api_instance.get_opsgenie_service(
        integration_service_id=OPSGENIE_SERVICE_DATA_ID,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.event_alert_type import EventAlertType
    from datadog_api_client.v1.model.event_priority import EventPriority


class EventCreateRequest(ModelNormal):
    validations = {
        "aggregation_key": {
            "max_length": 100,
        },
        "text": {
            "max_length": 4000,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.event_alert_type import EventAlertType
        from datadog_api_client.v1.model.event_priority import EventPriority

        return {
            "aggregation_key": (str,),
            "alert_type": (EventAlertType,),
            "date_happened": (int,),
            "device_name": (str,),
            "host": (str,),
            "priority": (EventPriority,),
            "related_event_id": (int,),
            "source_type_name": (str,),
            "tags": ([str],),
            "text": (str,),
            "title": (str,),
        }

    attribute_map = {
        "aggregation_key": "aggregation_key",
        "alert_type": "alert_type",
        "date_happened": "date_happened",
        "device_name": "device_name",
        "host": "host",
        "priority": "priority",
        "related_event_id": "related_event_id",
        "source_type_name": "source_type_name",
        "tags": "tags",
        "text": "text",
        "title": "title",
    }

    def __init__(
        self_,
        text: str,
        title: str,
        aggregation_key: Union[str, UnsetType] = unset,
        alert_type: Union[EventAlertType, UnsetType] = unset,
        date_happened: Union[int, UnsetType] = unset,
        device_name: Union[str, UnsetType] = unset,
        host: Union[str, UnsetType] = unset,
        priority: Union[EventPriority, none_type, UnsetType] = unset,
        related_event_id: Union[int, UnsetType] = unset,
        source_type_name: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Object representing an event.

        :param aggregation_key: An arbitrary string to use for aggregation. Limited to 100 characters.
            If you specify a key, all events using that key are grouped together in the Event Stream.
        :type aggregation_key: str, optional

        :param alert_type: If an alert event is enabled, set its type.
            For example, ``error`` , ``warning`` , ``info`` , ``success`` , ``user_update`` ,
            ``recommendation`` , and ``snapshot``.
        :type alert_type: EventAlertType, optional

        :param date_happened: POSIX timestamp of the event. Must be sent as an integer (that is no quotes).
            Limited to events no older than 18 hours
        :type date_happened: int, optional

        :param device_name: A device name.
        :type device_name: str, optional

        :param host: Host name to associate with the event.
            Any tags associated with the host are also applied to this event.
        :type host: str, optional

        :param priority: The priority of the event. For example, ``normal`` or ``low``.
        :type priority: EventPriority, none_type, optional

        :param related_event_id: ID of the parent event. Must be sent as an integer (that is no quotes).
        :type related_event_id: int, optional

        :param source_type_name: The type of event being posted. Option examples include nagios, hudson, jenkins, my_apps, chef, puppet, git, bitbucket, etc.
            A complete list of source attribute values `available here <https://docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value>`_.
        :type source_type_name: str, optional

        :param tags: A list of tags to apply to the event.
        :type tags: [str], optional

        :param text: The body of the event. Limited to 4000 characters. The text supports markdown.
            To use markdown in the event text, start the text block with ``%%% \\n`` and end the text block with ``\\n %%%``.
            Use ``msg_text`` with the Datadog Ruby library.
        :type text: str

        :param title: The event title.
        :type title: str
        """
        if aggregation_key is not unset:
            kwargs["aggregation_key"] = aggregation_key
        if alert_type is not unset:
            kwargs["alert_type"] = alert_type
        if date_happened is not unset:
            kwargs["date_happened"] = date_happened
        if device_name is not unset:
            kwargs["device_name"] = device_name
        if host is not unset:
            kwargs["host"] = host
        if priority is not unset:
            kwargs["priority"] = priority
        if related_event_id is not unset:
            kwargs["related_event_id"] = related_event_id
        if source_type_name is not unset:
            kwargs["source_type_name"] = source_type_name
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)

        self_.text = text
        self_.title = title



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_rule_response import SecurityMonitoringRuleResponse
    from datadog_api_client.v2.model.response_meta_attributes import ResponseMetaAttributes
    from datadog_api_client.v2.model.security_monitoring_standard_rule_response import (
        SecurityMonitoringStandardRuleResponse,
    )
    from datadog_api_client.v2.model.security_monitoring_signal_rule_response import (
        SecurityMonitoringSignalRuleResponse,
    )


class SecurityMonitoringListRulesResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_rule_response import SecurityMonitoringRuleResponse
        from datadog_api_client.v2.model.response_meta_attributes import ResponseMetaAttributes

        return {
            "data": ([SecurityMonitoringRuleResponse],),
            "meta": (ResponseMetaAttributes,),
        }

    attribute_map = {
        "data": "data",
        "meta": "meta",
    }

    def __init__(
        self_,
        data: Union[
            List[
                Union[
                    SecurityMonitoringRuleResponse,
                    SecurityMonitoringStandardRuleResponse,
                    SecurityMonitoringSignalRuleResponse,
                ]
            ],
            UnsetType,
        ] = unset,
        meta: Union[ResponseMetaAttributes, UnsetType] = unset,
        **kwargs,
    ):
        """
        List of rules.

        :param data: Array containing the list of rules.
        :type data: [SecurityMonitoringRuleResponse], optional

        :param meta: Object describing meta attributes of response.
        :type meta: ResponseMetaAttributes, optional
        """
        if data is not unset:
            kwargs["data"] = data
        if meta is not unset:
            kwargs["meta"] = meta
        super().__init__(kwargs)



"""
Get hourly usage for cloud workload security returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.usage_metering_api import UsageMeteringApi
from datetime import datetime
from dateutil.tz import tzutc

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = UsageMeteringApi(api_client)
    response = api_instance.get_usage_cws(
        start_hr=datetime(2021, 11, 11, 11, 11, 11, 111000, tzinfo=tzutc()),
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MonitorFormulaAndFunctionEventsDataSource(ModelSimple):
    """
    Data source for event platform-based queries.

    :param value: Must be one of ["rum", "ci_pipelines", "ci_tests", "audit", "events", "logs", "spans"].
    :type value: str
    """

    allowed_values = {
        "rum",
        "ci_pipelines",
        "ci_tests",
        "audit",
        "events",
        "logs",
        "spans",
    }
    RUM: ClassVar["MonitorFormulaAndFunctionEventsDataSource"]
    CI_PIPELINES: ClassVar["MonitorFormulaAndFunctionEventsDataSource"]
    CI_TESTS: ClassVar["MonitorFormulaAndFunctionEventsDataSource"]
    AUDIT: ClassVar["MonitorFormulaAndFunctionEventsDataSource"]
    EVENTS: ClassVar["MonitorFormulaAndFunctionEventsDataSource"]
    LOGS: ClassVar["MonitorFormulaAndFunctionEventsDataSource"]
    SPANS: ClassVar["MonitorFormulaAndFunctionEventsDataSource"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MonitorFormulaAndFunctionEventsDataSource.RUM = MonitorFormulaAndFunctionEventsDataSource("rum")
MonitorFormulaAndFunctionEventsDataSource.CI_PIPELINES = MonitorFormulaAndFunctionEventsDataSource("ci_pipelines")
MonitorFormulaAndFunctionEventsDataSource.CI_TESTS = MonitorFormulaAndFunctionEventsDataSource("ci_tests")
MonitorFormulaAndFunctionEventsDataSource.AUDIT = MonitorFormulaAndFunctionEventsDataSource("audit")
MonitorFormulaAndFunctionEventsDataSource.EVENTS = MonitorFormulaAndFunctionEventsDataSource("events")
MonitorFormulaAndFunctionEventsDataSource.LOGS = MonitorFormulaAndFunctionEventsDataSource("logs")
MonitorFormulaAndFunctionEventsDataSource.SPANS = MonitorFormulaAndFunctionEventsDataSource("spans")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_ci_test import SyntheticsCITest


class SyntheticsCITestBody(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_ci_test import SyntheticsCITest

        return {
            "tests": ([SyntheticsCITest],),
        }

    attribute_map = {
        "tests": "tests",
    }

    def __init__(self_, tests: Union[List[SyntheticsCITest], UnsetType] = unset, **kwargs):
        """
        Object describing the synthetics tests to trigger.

        :param tests: Individual synthetics test.
        :type tests: [SyntheticsCITest], optional
        """
        if tests is not unset:
            kwargs["tests"] = tests
        super().__init__(kwargs)



"""
Create a new dashboard with geomap widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.formula_and_function_event_aggregation import FormulaAndFunctionEventAggregation
from datadog_api_client.v1.model.formula_and_function_event_query_definition import (
    FormulaAndFunctionEventQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_event_query_definition_compute import (
    FormulaAndFunctionEventQueryDefinitionCompute,
)
from datadog_api_client.v1.model.formula_and_function_event_query_definition_search import (
    FormulaAndFunctionEventQueryDefinitionSearch,
)
from datadog_api_client.v1.model.formula_and_function_event_query_group_by import FormulaAndFunctionEventQueryGroupBy
from datadog_api_client.v1.model.formula_and_function_event_query_group_by_sort import (
    FormulaAndFunctionEventQueryGroupBySort,
)
from datadog_api_client.v1.model.formula_and_function_events_data_source import FormulaAndFunctionEventsDataSource
from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
from datadog_api_client.v1.model.geomap_widget_definition import GeomapWidgetDefinition
from datadog_api_client.v1.model.geomap_widget_definition_style import GeomapWidgetDefinitionStyle
from datadog_api_client.v1.model.geomap_widget_definition_type import GeomapWidgetDefinitionType
from datadog_api_client.v1.model.geomap_widget_definition_view import GeomapWidgetDefinitionView
from datadog_api_client.v1.model.geomap_widget_request import GeomapWidgetRequest
from datadog_api_client.v1.model.query_sort_order import QuerySortOrder
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_formula import WidgetFormula
from datadog_api_client.v1.model.widget_formula_limit import WidgetFormulaLimit
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
from datadog_api_client.v1.model.widget_time import WidgetTime

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_geomap_widget",
    description=None,
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=47,
                height=30,
            ),
            definition=GeomapWidgetDefinition(
                title="",
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                time=WidgetTime(),
                type=GeomapWidgetDefinitionType.GEOMAP,
                requests=[
                    GeomapWidgetRequest(
                        formulas=[
                            WidgetFormula(
                                formula="query1",
                                limit=WidgetFormulaLimit(
                                    count=250,
                                    order=QuerySortOrder.DESC,
                                ),
                            ),
                        ],
                        queries=[
                            FormulaAndFunctionEventQueryDefinition(
                                name="query1",
                                data_source=FormulaAndFunctionEventsDataSource.RUM,
                                search=FormulaAndFunctionEventQueryDefinitionSearch(
                                    query="",
                                ),
                                indexes=[
                                    "*",
                                ],
                                compute=FormulaAndFunctionEventQueryDefinitionCompute(
                                    aggregation=FormulaAndFunctionEventAggregation.COUNT,
                                ),
                                group_by=[
                                    FormulaAndFunctionEventQueryGroupBy(
                                        facet="@geo.country_iso_code",
                                        limit=250,
                                        sort=FormulaAndFunctionEventQueryGroupBySort(
                                            order=QuerySortOrder.DESC,
                                            aggregation=FormulaAndFunctionEventAggregation.COUNT,
                                        ),
                                    ),
                                ],
                            ),
                        ],
                        response_format=FormulaAndFunctionResponseFormat.SCALAR,
                    ),
                ],
                style=GeomapWidgetDefinitionStyle(
                    palette="hostmap_blues",
                    palette_flip=False,
                ),
                view=GeomapWidgetDefinitionView(
                    focus="WORLD",
                ),
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
    from datadog_api_client.v1.model.widget_event import WidgetEvent
    from datadog_api_client.v1.model.timeseries_widget_legend_column import TimeseriesWidgetLegendColumn
    from datadog_api_client.v1.model.timeseries_widget_legend_layout import TimeseriesWidgetLegendLayout
    from datadog_api_client.v1.model.widget_marker import WidgetMarker
    from datadog_api_client.v1.model.timeseries_widget_request import TimeseriesWidgetRequest
    from datadog_api_client.v1.model.widget_axis import WidgetAxis
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.timeseries_widget_definition_type import TimeseriesWidgetDefinitionType


class TimeseriesWidgetDefinition(ModelNormal):
    validations = {
        "requests": {
            "min_items": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
        from datadog_api_client.v1.model.widget_event import WidgetEvent
        from datadog_api_client.v1.model.timeseries_widget_legend_column import TimeseriesWidgetLegendColumn
        from datadog_api_client.v1.model.timeseries_widget_legend_layout import TimeseriesWidgetLegendLayout
        from datadog_api_client.v1.model.widget_marker import WidgetMarker
        from datadog_api_client.v1.model.timeseries_widget_request import TimeseriesWidgetRequest
        from datadog_api_client.v1.model.widget_axis import WidgetAxis
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.timeseries_widget_definition_type import TimeseriesWidgetDefinitionType

        return {
            "custom_links": ([WidgetCustomLink],),
            "events": ([WidgetEvent],),
            "legend_columns": ([TimeseriesWidgetLegendColumn],),
            "legend_layout": (TimeseriesWidgetLegendLayout,),
            "legend_size": (str,),
            "markers": ([WidgetMarker],),
            "requests": ([TimeseriesWidgetRequest],),
            "right_yaxis": (WidgetAxis,),
            "show_legend": (bool,),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (TimeseriesWidgetDefinitionType,),
            "yaxis": (WidgetAxis,),
        }

    attribute_map = {
        "custom_links": "custom_links",
        "events": "events",
        "legend_columns": "legend_columns",
        "legend_layout": "legend_layout",
        "legend_size": "legend_size",
        "markers": "markers",
        "requests": "requests",
        "right_yaxis": "right_yaxis",
        "show_legend": "show_legend",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
        "yaxis": "yaxis",
    }

    def __init__(
        self_,
        requests: List[TimeseriesWidgetRequest],
        type: TimeseriesWidgetDefinitionType,
        custom_links: Union[List[WidgetCustomLink], UnsetType] = unset,
        events: Union[List[WidgetEvent], UnsetType] = unset,
        legend_columns: Union[List[TimeseriesWidgetLegendColumn], UnsetType] = unset,
        legend_layout: Union[TimeseriesWidgetLegendLayout, UnsetType] = unset,
        legend_size: Union[str, UnsetType] = unset,
        markers: Union[List[WidgetMarker], UnsetType] = unset,
        right_yaxis: Union[WidgetAxis, UnsetType] = unset,
        show_legend: Union[bool, UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        yaxis: Union[WidgetAxis, UnsetType] = unset,
        **kwargs,
    ):
        """
        The timeseries visualization allows you to display the evolution of one or more metrics, log events, or Indexed Spans over time.

        :param custom_links: List of custom links.
        :type custom_links: [WidgetCustomLink], optional

        :param events: List of widget events.
        :type events: [WidgetEvent], optional

        :param legend_columns: Columns displayed in the legend.
        :type legend_columns: [TimeseriesWidgetLegendColumn], optional

        :param legend_layout: Layout of the legend.
        :type legend_layout: TimeseriesWidgetLegendLayout, optional

        :param legend_size: Available legend sizes for a widget. Should be one of "0", "2", "4", "8", "16", or "auto".
        :type legend_size: str, optional

        :param markers: List of markers.
        :type markers: [WidgetMarker], optional

        :param requests: List of timeseries widget requests.
        :type requests: [TimeseriesWidgetRequest]

        :param right_yaxis: Axis controls for the widget.
        :type right_yaxis: WidgetAxis, optional

        :param show_legend: (screenboard only) Show the legend for this widget.
        :type show_legend: bool, optional

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: Title of your widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the timeseries widget.
        :type type: TimeseriesWidgetDefinitionType

        :param yaxis: Axis controls for the widget.
        :type yaxis: WidgetAxis, optional
        """
        if custom_links is not unset:
            kwargs["custom_links"] = custom_links
        if events is not unset:
            kwargs["events"] = events
        if legend_columns is not unset:
            kwargs["legend_columns"] = legend_columns
        if legend_layout is not unset:
            kwargs["legend_layout"] = legend_layout
        if legend_size is not unset:
            kwargs["legend_size"] = legend_size
        if markers is not unset:
            kwargs["markers"] = markers
        if right_yaxis is not unset:
            kwargs["right_yaxis"] = right_yaxis
        if show_legend is not unset:
            kwargs["show_legend"] = show_legend
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        if yaxis is not unset:
            kwargs["yaxis"] = yaxis
        super().__init__(kwargs)

        self_.requests = requests
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.funnel_source import FunnelSource
    from datadog_api_client.v1.model.funnel_step import FunnelStep


class FunnelQuery(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.funnel_source import FunnelSource
        from datadog_api_client.v1.model.funnel_step import FunnelStep

        return {
            "data_source": (FunnelSource,),
            "query_string": (str,),
            "steps": ([FunnelStep],),
        }

    attribute_map = {
        "data_source": "data_source",
        "query_string": "query_string",
        "steps": "steps",
    }

    def __init__(self_, data_source: FunnelSource, query_string: str, steps: List[FunnelStep], **kwargs):
        """
        Updated funnel widget.

        :param data_source: Source from which to query items to display in the funnel.
        :type data_source: FunnelSource

        :param query_string: The widget query.
        :type query_string: str

        :param steps: List of funnel steps.
        :type steps: [FunnelStep]
        """
        super().__init__(kwargs)

        self_.data_source = data_source
        self_.query_string = query_string
        self_.steps = steps



"""
Get Tags returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.tags_api import TagsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = TagsApi(api_client)
    response = api_instance.list_host_tags()

    print(response)



"""
Create an API test returns "OK - Returns the created test details." response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType
from datadog_api_client.v1.model.synthetics_browser_test_rum_settings import SyntheticsBrowserTestRumSettings
from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles
from datadog_api_client.v1.model.synthetics_test_ci_options import SyntheticsTestCiOptions
from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
from datadog_api_client.v1.model.synthetics_test_execution_rule import SyntheticsTestExecutionRule
from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
from datadog_api_client.v1.model.synthetics_test_options_monitor_options import SyntheticsTestOptionsMonitorOptions
from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus
from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest

body = SyntheticsAPITest(
    config=SyntheticsAPITestConfig(
        assertions=[
            SyntheticsAssertionTarget(
                operator=SyntheticsAssertionOperator.LESS_THAN,
                target=1000,
                type=SyntheticsAssertionType.RESPONSE_TIME,
            ),
        ],
        request=SyntheticsTestRequest(
            method="GET",
            url="https://example.com",
        ),
    ),
    locations=[
        "aws:eu-west-3",
    ],
    message="Notification message",
    name="Example test name",
    options=SyntheticsTestOptions(
        ci=SyntheticsTestCiOptions(
            execution_rule=SyntheticsTestExecutionRule.BLOCKING,
        ),
        device_ids=[
            SyntheticsDeviceID.LAPTOP_LARGE,
        ],
        monitor_options=SyntheticsTestOptionsMonitorOptions(),
        restricted_roles=SyntheticsRestrictedRoles(
            [
                "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            ]
        ),
        retry=SyntheticsTestOptionsRetry(),
        rum_settings=SyntheticsBrowserTestRumSettings(
            application_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            client_token_id=12345,
            is_enabled=True,
        ),
    ),
    status=SyntheticsTestPauseStatus.LIVE,
    subtype=SyntheticsTestDetailsSubType.HTTP,
    tags=[
        "env:production",
    ],
    type=SyntheticsAPITestType.API,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.create_synthetics_api_test(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.creator import Creator


class DashboardList(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.creator import Creator

        return {
            "author": (Creator,),
            "created": (datetime,),
            "dashboard_count": (int,),
            "id": (int,),
            "is_favorite": (bool,),
            "modified": (datetime,),
            "name": (str,),
            "type": (str,),
        }

    attribute_map = {
        "author": "author",
        "created": "created",
        "dashboard_count": "dashboard_count",
        "id": "id",
        "is_favorite": "is_favorite",
        "modified": "modified",
        "name": "name",
        "type": "type",
    }
    read_only_vars = {
        "author",
        "created",
        "dashboard_count",
        "id",
        "is_favorite",
        "modified",
        "type",
    }

    def __init__(
        self_,
        name: str,
        author: Union[Creator, UnsetType] = unset,
        created: Union[datetime, UnsetType] = unset,
        dashboard_count: Union[int, UnsetType] = unset,
        id: Union[int, UnsetType] = unset,
        is_favorite: Union[bool, UnsetType] = unset,
        modified: Union[datetime, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Your Datadog Dashboards.

        :param author: Object describing the creator of the shared element.
        :type author: Creator, optional

        :param created: Date of creation of the dashboard list.
        :type created: datetime, optional

        :param dashboard_count: The number of dashboards in the list.
        :type dashboard_count: int, optional

        :param id: The ID of the dashboard list.
        :type id: int, optional

        :param is_favorite: Whether or not the list is in the favorites.
        :type is_favorite: bool, optional

        :param modified: Date of last edition of the dashboard list.
        :type modified: datetime, optional

        :param name: The name of the dashboard list.
        :type name: str

        :param type: The type of dashboard list.
        :type type: str, optional
        """
        if author is not unset:
            kwargs["author"] = author
        if created is not unset:
            kwargs["created"] = created
        if dashboard_count is not unset:
            kwargs["dashboard_count"] = dashboard_count
        if id is not unset:
            kwargs["id"] = id
        if is_favorite is not unset:
            kwargs["is_favorite"] = is_favorite
        if modified is not unset:
            kwargs["modified"] = modified
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)

        self_.name = name



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class WidgetMarker(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "display_type": (str,),
            "label": (str,),
            "time": (str,),
            "value": (str,),
        }

    attribute_map = {
        "display_type": "display_type",
        "label": "label",
        "time": "time",
        "value": "value",
    }

    def __init__(
        self_,
        value: str,
        display_type: Union[str, UnsetType] = unset,
        label: Union[str, UnsetType] = unset,
        time: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Markers allow you to add visual conditional formatting for your graphs.

        :param display_type: Combination of:

            * A severity error, warning, ok, or info
            * A line type: dashed, solid, or bold
              In this case of a Distribution widget, this can be set to be ``x_axis_percentile``.
        :type display_type: str, optional

        :param label: Label to display over the marker.
        :type label: str, optional

        :param time: Timestamp for the widget.
        :type time: str, optional

        :param value: Value to apply. Can be a single value y = 15 or a range of values 0 < y < 10.
        :type value: str
        """
        if display_type is not unset:
            kwargs["display_type"] = display_type
        if label is not unset:
            kwargs["label"] = label
        if time is not unset:
            kwargs["time"] = time
        super().__init__(kwargs)

        self_.value = value



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.service_check_status import ServiceCheckStatus


class ServiceCheck(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.service_check_status import ServiceCheckStatus

        return {
            "check": (str,),
            "host_name": (str,),
            "message": (str,),
            "status": (ServiceCheckStatus,),
            "tags": ([str],),
            "timestamp": (int,),
        }

    attribute_map = {
        "check": "check",
        "host_name": "host_name",
        "message": "message",
        "status": "status",
        "tags": "tags",
        "timestamp": "timestamp",
    }

    def __init__(
        self_,
        check: str,
        host_name: str,
        status: ServiceCheckStatus,
        tags: List[str],
        message: Union[str, UnsetType] = unset,
        timestamp: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        An object containing service check and status.

        :param check: The check.
        :type check: str

        :param host_name: The host name correlated with the check.
        :type host_name: str

        :param message: Message containing check status.
        :type message: str, optional

        :param status: The status of a service check. Set to ``0`` for OK, ``1`` for warning, ``2`` for critical, and ``3`` for unknown.
        :type status: ServiceCheckStatus

        :param tags: Tags related to a check.
        :type tags: [str]

        :param timestamp: Time of check.
        :type timestamp: int, optional
        """
        if message is not unset:
            kwargs["message"] = message
        if timestamp is not unset:
            kwargs["timestamp"] = timestamp
        super().__init__(kwargs)

        self_.check = check
        self_.host_name = host_name
        self_.status = status
        self_.tags = tags



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.application_key import ApplicationKey


class ApplicationKeyResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.application_key import ApplicationKey

        return {
            "application_key": (ApplicationKey,),
        }

    attribute_map = {
        "application_key": "application_key",
    }

    def __init__(self_, application_key: Union[ApplicationKey, UnsetType] = unset, **kwargs):
        """
        An application key response.

        :param application_key: An application key with its associated metadata.
        :type application_key: ApplicationKey, optional
        """
        if application_key is not unset:
            kwargs["application_key"] = application_key
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.v1.model.gcp_account import GCPAccount
from datadog_api_client.v1.model.gcp_account_list_response import GCPAccountListResponse


class GCPIntegrationApi:
    """
    Configure your Datadog-Google Cloud Platform (GCP) integration directly
    through the Datadog API. Read more about the `Datadog-Google Cloud Platform integration <https://docs.datadoghq.com/integrations/google_cloud_platform>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_gcp_integration_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/gcp",
                "operation_id": "create_gcp_integration",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (GCPAccount,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_gcp_integration_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/gcp",
                "operation_id": "delete_gcp_integration",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (GCPAccount,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._list_gcp_integration_endpoint = _Endpoint(
            settings={
                "response_type": (GCPAccountListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/gcp",
                "operation_id": "list_gcp_integration",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_gcp_integration_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/gcp",
                "operation_id": "update_gcp_integration",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (GCPAccount,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_gcp_integration(
        self,
        body: GCPAccount,
    ) -> dict:
        """Create a GCP integration.

        Create a Datadog-GCP integration.

        :param body: Create a Datadog-GCP integration.
        :type body: GCPAccount
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_gcp_integration_endpoint.call_with_http_info(**kwargs)

    def delete_gcp_integration(
        self,
        body: GCPAccount,
    ) -> dict:
        """Delete a GCP integration.

        Delete a given Datadog-GCP integration.

        :param body: Delete a given Datadog-GCP integration.
        :type body: GCPAccount
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._delete_gcp_integration_endpoint.call_with_http_info(**kwargs)

    def list_gcp_integration(
        self,
    ) -> GCPAccountListResponse:
        """List all GCP integrations.

        List all Datadog-GCP integrations configured in your Datadog account.

        :rtype: GCPAccountListResponse
        """
        kwargs: Dict[str, Any] = {}
        return self._list_gcp_integration_endpoint.call_with_http_info(**kwargs)

    def update_gcp_integration(
        self,
        body: GCPAccount,
    ) -> dict:
        """Update a GCP integration.

        Update a Datadog-GCP integrations host_filters and/or auto-mute.
        Requires a ``project_id`` and ``client_email`` , however these fields cannot be updated.
        If you need to update these fields, delete and use the create ( ``POST`` ) endpoint.
        The unspecified fields will keep their original values.

        :param body: Update a Datadog-GCP integration.
        :type body: GCPAccount
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._update_gcp_integration_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class MetricsQueryUnit(ModelNormal):
    _nullable = True

    @cached_property
    def openapi_types(_):
        return {
            "family": (str,),
            "name": (str,),
            "plural": (str,),
            "scale_factor": (float,),
            "short_name": (str,),
        }

    attribute_map = {
        "family": "family",
        "name": "name",
        "plural": "plural",
        "scale_factor": "scale_factor",
        "short_name": "short_name",
    }
    read_only_vars = {
        "family",
        "name",
        "plural",
        "scale_factor",
        "short_name",
    }

    def __init__(
        self_,
        family: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        plural: Union[str, UnsetType] = unset,
        scale_factor: Union[float, UnsetType] = unset,
        short_name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing the metric unit family, scale factor, name, and short name.

        :param family: Unit family, allows for conversion between units of the same family, for scaling.
        :type family: str, optional

        :param name: Unit name
        :type name: str, optional

        :param plural: Plural form of the unit name.
        :type plural: str, optional

        :param scale_factor: Factor for scaling between units of the same family.
        :type scale_factor: float, optional

        :param short_name: Abbreviation of the unit.
        :type short_name: str, optional
        """
        if family is not unset:
            kwargs["family"] = family
        if name is not unset:
            kwargs["name"] = name
        if plural is not unset:
            kwargs["plural"] = plural
        if scale_factor is not unset:
            kwargs["scale_factor"] = scale_factor
        if short_name is not unset:
            kwargs["short_name"] = short_name
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsStepType(ModelSimple):
    """
    Step type used in your Synthetic test.

    :param value: Must be one of ["assertCurrentUrl", "assertElementAttribute", "assertElementContent", "assertElementPresent", "assertEmail", "assertFileDownload", "assertFromJavascript", "assertPageContains", "assertPageLacks", "click", "extractFromJavascript", "extractVariable", "goToEmailLink", "goToUrl", "goToUrlAndMeasureTti", "hover", "playSubTest", "pressKey", "refresh", "runApiTest", "scroll", "selectOption", "typeText", "uploadFiles", "wait"].
    :type value: str
    """

    allowed_values = {
        "assertCurrentUrl",
        "assertElementAttribute",
        "assertElementContent",
        "assertElementPresent",
        "assertEmail",
        "assertFileDownload",
        "assertFromJavascript",
        "assertPageContains",
        "assertPageLacks",
        "click",
        "extractFromJavascript",
        "extractVariable",
        "goToEmailLink",
        "goToUrl",
        "goToUrlAndMeasureTti",
        "hover",
        "playSubTest",
        "pressKey",
        "refresh",
        "runApiTest",
        "scroll",
        "selectOption",
        "typeText",
        "uploadFiles",
        "wait",
    }
    ASSERT_CURRENT_URL: ClassVar["SyntheticsStepType"]
    ASSERT_ELEMENT_ATTRIBUTE: ClassVar["SyntheticsStepType"]
    ASSERT_ELEMENT_CONTENT: ClassVar["SyntheticsStepType"]
    ASSERT_ELEMENT_PRESENT: ClassVar["SyntheticsStepType"]
    ASSERT_EMAIL: ClassVar["SyntheticsStepType"]
    ASSERT_FILE_DOWNLOAD: ClassVar["SyntheticsStepType"]
    ASSERT_FROM_JAVASCRIPT: ClassVar["SyntheticsStepType"]
    ASSERT_PAGE_CONTAINS: ClassVar["SyntheticsStepType"]
    ASSERT_PAGE_LACKS: ClassVar["SyntheticsStepType"]
    CLICK: ClassVar["SyntheticsStepType"]
    EXTRACT_FROM_JAVASCRIPT: ClassVar["SyntheticsStepType"]
    EXTRACT_VARIABLE: ClassVar["SyntheticsStepType"]
    GO_TO_EMAIL_LINK: ClassVar["SyntheticsStepType"]
    GO_TO_URL: ClassVar["SyntheticsStepType"]
    GO_TO_URL_AND_MEASURE_TTI: ClassVar["SyntheticsStepType"]
    HOVER: ClassVar["SyntheticsStepType"]
    PLAY_SUB_TEST: ClassVar["SyntheticsStepType"]
    PRESS_KEY: ClassVar["SyntheticsStepType"]
    REFRESH: ClassVar["SyntheticsStepType"]
    RUN_API_TEST: ClassVar["SyntheticsStepType"]
    SCROLL: ClassVar["SyntheticsStepType"]
    SELECT_OPTION: ClassVar["SyntheticsStepType"]
    TYPE_TEXT: ClassVar["SyntheticsStepType"]
    UPLOAD_FILES: ClassVar["SyntheticsStepType"]
    WAIT: ClassVar["SyntheticsStepType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsStepType.ASSERT_CURRENT_URL = SyntheticsStepType("assertCurrentUrl")
SyntheticsStepType.ASSERT_ELEMENT_ATTRIBUTE = SyntheticsStepType("assertElementAttribute")
SyntheticsStepType.ASSERT_ELEMENT_CONTENT = SyntheticsStepType("assertElementContent")
SyntheticsStepType.ASSERT_ELEMENT_PRESENT = SyntheticsStepType("assertElementPresent")
SyntheticsStepType.ASSERT_EMAIL = SyntheticsStepType("assertEmail")
SyntheticsStepType.ASSERT_FILE_DOWNLOAD = SyntheticsStepType("assertFileDownload")
SyntheticsStepType.ASSERT_FROM_JAVASCRIPT = SyntheticsStepType("assertFromJavascript")
SyntheticsStepType.ASSERT_PAGE_CONTAINS = SyntheticsStepType("assertPageContains")
SyntheticsStepType.ASSERT_PAGE_LACKS = SyntheticsStepType("assertPageLacks")
SyntheticsStepType.CLICK = SyntheticsStepType("click")
SyntheticsStepType.EXTRACT_FROM_JAVASCRIPT = SyntheticsStepType("extractFromJavascript")
SyntheticsStepType.EXTRACT_VARIABLE = SyntheticsStepType("extractVariable")
SyntheticsStepType.GO_TO_EMAIL_LINK = SyntheticsStepType("goToEmailLink")
SyntheticsStepType.GO_TO_URL = SyntheticsStepType("goToUrl")
SyntheticsStepType.GO_TO_URL_AND_MEASURE_TTI = SyntheticsStepType("goToUrlAndMeasureTti")
SyntheticsStepType.HOVER = SyntheticsStepType("hover")
SyntheticsStepType.PLAY_SUB_TEST = SyntheticsStepType("playSubTest")
SyntheticsStepType.PRESS_KEY = SyntheticsStepType("pressKey")
SyntheticsStepType.REFRESH = SyntheticsStepType("refresh")
SyntheticsStepType.RUN_API_TEST = SyntheticsStepType("runApiTest")
SyntheticsStepType.SCROLL = SyntheticsStepType("scroll")
SyntheticsStepType.SELECT_OPTION = SyntheticsStepType("selectOption")
SyntheticsStepType.TYPE_TEXT = SyntheticsStepType("typeText")
SyntheticsStepType.UPLOAD_FILES = SyntheticsStepType("uploadFiles")
SyntheticsStepType.WAIT = SyntheticsStepType("wait")
